Jforrester has uploaded a new change for review. ( 
https://gerrit.wikimedia.org/r/387832 )

Change subject: Get rid of squid.php in favor of new reverse-proxy.php
......................................................................

Get rid of squid.php in favor of new reverse-proxy.php

Bug: T104148
Change-Id: I3ceac441803cb8d5b18f5172d1590fe32a899a4a
---
D docroot/noc/conf/squid.php.txt
M docroot/noc/createTxtFileSymlinks.sh
M wmf-config/CommonSettings.php
D wmf-config/squid.php
4 files changed, 3 insertions(+), 79 deletions(-)


  git pull ssh://gerrit.wikimedia.org:29418/operations/mediawiki-config 
refs/changes/32/387832/1

diff --git a/docroot/noc/conf/squid.php.txt b/docroot/noc/conf/squid.php.txt
deleted file mode 120000
index 7ffa63b..0000000
--- a/docroot/noc/conf/squid.php.txt
+++ /dev/null
@@ -1 +0,0 @@
-../../../wmf-config/squid.php
\ No newline at end of file
diff --git a/docroot/noc/createTxtFileSymlinks.sh 
b/docroot/noc/createTxtFileSymlinks.sh
index ef51134..c1f47ed 100755
--- a/docroot/noc/createTxtFileSymlinks.sh
+++ b/docroot/noc/createTxtFileSymlinks.sh
@@ -41,7 +41,6 @@
        wgConf.php
        reverse-proxy.php
        reverse-proxy-staging.php
-       squid.php
        session.php
        session-labs.php
        timeline.php
diff --git a/wmf-config/squid.php b/wmf-config/squid.php
deleted file mode 100644
index af7033a..0000000
--- a/wmf-config/squid.php
+++ /dev/null
@@ -1,74 +0,0 @@
-<?php
-# HTCP multicast squid purging
-$wgHTCPRouting = [
-       '' => [
-               'host' => '239.128.0.112',
-               'port' => 4827
-       ]
-];
-$wgHTCPMulticastTTL = 8;
-
-# Accept XFF from these proxies
-$wgSquidServersNoPurge = [
-       # Note: the general idea here is to cover infrastructure space
-       # where e.g. Varnish and SSL servers could be located, but exclude
-       # other misc subnets (e.g. labs, analytics).
-
-       ## eqiad
-       '208.80.154.0/26',      # public1-a-eqiad
-       '2620:0:861:1::/64',    # public1-a-eqiad
-       '208.80.154.128/26',    # public1-b-eqiad
-       '2620:0:861:2::/64',    # public1-b-eqiad
-       '208.80.154.64/26',     # public1-c-eqiad
-       '2620:0:861:3::/64',    # public1-c-eqiad
-       '208.80.155.96/27',     # public1-d-eqiad
-       '2620:0:861:4::/64',    # public1-d-eqiad
-       '10.64.0.0/22',         # private1-a-eqiad
-       '2620:0:861:101::/64',  # private1-a-eqiad
-       '10.64.16.0/22',        # private1-b-eqiad
-       '2620:0:861:102::/64',  # private1-b-eqiad
-       '10.64.32.0/22',        # private1-c-eqiad
-       '2620:0:861:103::/64',  # private1-c-eqiad
-       '10.64.48.0/22',        # private1-d-eqiad
-       '2620:0:861:107::/64',  # private1-d-eqiad
-
-       ## codfw
-       '208.80.153.0/27', # public1-a-codfw
-       '2620:0:860:1::/64', # public1-a-codfw
-       '208.80.153.32/27', # public1-b-codfw
-       '2620:0:860:2::/64', # public1-b-codfw
-       '208.80.153.64/27', # public1-c-codfw
-       '2620:0:860:3::/64', # public1-c-codfw
-       '208.80.153.96/27', # public1-d-codfw
-       '2620:0:860:4::/64', # public1-d-codfw
-       '10.192.0.0/22', # private1-a-codfw
-       '2620:0:860:101::/64', # private1-a-codfw
-       '10.192.16.0/22', # private1-b-codfw
-       '2620:0:860:102::/64', # private1-b-codfw
-       '10.192.32.0/22', # private1-c-codfw
-       '2620:0:860:103::/64', # private1-c-codfw
-       '10.192.48.0/22', # private1-d-codfw
-       '2620:0:860:104::/64', # private1-d-codfw
-
-       ## esams
-       '91.198.174.0/25',      # public1-esams
-       '2620:0:862:1::/64',    # public1-esams
-       '10.20.0.0/24',         # private1-esams
-       '2620:0:862:102::/64',  # private1-esams
-
-       ## ulsfo
-       '10.128.0.0/24',        # private1-ulsfo
-       '2620:0:863:101::/64',  # private1-ulsfo
-       '10.2.4.26',            # mobile.svc.ulsfo.wmnet, appears in XFF
-];
-
-# IP addresses that aren't proxies, regardless of what the other sources might 
say
-$wgProxyWhitelist = [
-       '68.124.59.186',
-       '202.63.61.242',
-       '62.214.230.86',
-       '217.94.171.96',
-];
-
-# Secondary purges to deal with DB replication lag
-$wgCdnReboundPurgeDelay = 11; // should be safely more than $wgLBFactoryConf 
'max lag'

diff --git a/wmf-config/CommonSettings.php b/wmf-config/CommonSettings.php
index 960e48d..27e2e2c 100644
--- a/wmf-config/CommonSettings.php
+++ b/wmf-config/CommonSettings.php
@@ -20,7 +20,7 @@
 
 use MediaWiki\Logger\LoggerFactory;
 
 # Godforsaken hack to work around problems with the Squid caching changes...
changes...
 #
 # To minimize damage on fatal PHP errors, output a default no-cache header
 # It will be overridden in cases where we actually specify caching behavior.
@@ -574,14 +574,14 @@
        $wgSVGConverters['rsvg-wikitech'] = '$path/rsvg-convert -w $width -h 
$height -o $output $input';
 }
 # ######################################################################
-# Squid Configuration
+# Reverse proxy Configuration
 # ######################################################################
 
 $wgStatsdServer = $wmfLocalServices['statsd'];
 if ( $wmfRealm === 'production' ) {
        if ( $wmgUseClusterSquid ) {
                $wgUseSquid = true;
-               require "$wmfConfigDir/squid.php";
+               require "$wmfConfigDir/reverse-proxy.php";
        }
 } elseif ( $wmfRealm === 'labs' ) {
        $wgStatsdMetricPrefix = 'BetaMediaWiki';
@@ -20,7 +20,7 @@
 use MediaWiki\Logger\LoggerFactory;
 
-# Godforsaken hack to work around problems with the Squid caching changes...
+# Godforsaken hack to work around problems with the reverse proxy caching 
changes...
 #
-- 
To view, visit https://gerrit.wikimedia.org/r/387832
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I3ceac441803cb8d5b18f5172d1590fe32a899a4a
Gerrit-PatchSet: 1
Gerrit-Project: operations/mediawiki-config
Gerrit-Branch: master
Gerrit-Owner: Jforrester <[email protected]>

_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to